function [Sfinal,f] = grasp_MRS(A,fun,betaOpt,T,k,name)
% A - Sparse adjacency (symmetric) matrix of the graph
% betaOpt = 1 => beta = 0.8 
% betaOpt = 2 => uniform discrete 0.1 to 1 [0.1 0.2 ... 1]
% fun = 1 - g(v) = t(v)/d(v) number of triangles(v) divided by the degree(v)
% fun = 2 - g(v) = d_{G(C U S)(v) degree in the induced neighborhood
%    fun = 31 - 1st iteration based on fun = 1, then pick the one that
%    increases our robustness the most
%    fun = 32 - 1st iteration based on fun = 2, then pick the one that
%    increases our robstuness the most
% T = number of iterations
% name - string; name of the files

f = -Inf;


for z=1:T
        
    if betaOpt == 1 
        beta = 0.8;
    else
        r = random('unid',10);
        beta = r/10;
    end
    
    
    [S] = grasp_MRS_ConstructionNew(A,fun,beta,k);

    [S, ~] = grasp_MRS_LocalSearch(A,S,k);
    
        
    [~,l] = eig(full(A(S,S)));
    lambdaS = log(1/length(l) * sum(exp(sum(l))));
    
    
    
    if lambdaS > f && length(l) == k
        
        Sfinal = S;
        f = lambdaS;
        save(strcat(name,num2str(fun),num2str(betaOpt),num2str(k),'RobSub'),'Sfinal')
         
    end
    
end


end