function [S] = grasp_MRS_ConstructionNew(A,fun,beta,k)

%%%% input %%%%%
% A - Sparse adjacency (symmetric) matrix of the graph
% fun - specifying the cost function to be use for each node
%    fun = 1 - g(v) = t(v)/d(v) number of triangles(v) divided by the degree(v)
%    fun = 2 - g(v) = d_{G(C U S)(v) degree in the induced neighborhood
%    fun = 31 - 1st iteration based on fun = 1, then pick the one that
%    increases our robustness the most
%    fun = 32 - 1st iteration based on fun = 2, then pick the one that
%    increases our robstuness the most
%    subgraph of S
% beta = greediness

%%%%%%%%%%%%%%%%

N = length(A);

% 0 = node not selected; 1 = node selected
counter = 0;
S = [];
C = (1:N)';
sampleRate = 0.5;
g = zeros(length(C),1);


C = C(randsample(length(C),ceil(sampleRate*length(C))));

cont = true;

%%%%% A(find(C), find(C)) consider non-zero entries of C and take each
%%%%% possible combination of the entries [1 2 3 4 ...] X [1 2 3 4 ...]

while length(S) < k && counter < k
    
    if (fun == 1 || fun == 31) && cont
        
        inputT = min(round(length([C;S])*0.1),200);
        
        if length([C;S]) < 100
            inputT = length([C;S]);
        end
        
        gUpDate = approxTriToDegreeRatio(A([C;S],[C;S]), inputT);
        
    elseif (fun == 2 || fun == 32) && cont
        
        gUpDate = neigborDegree(A([C;S],[C;S]));
        
    else
        
        gUpDate = eigenScore(A,C,S);
        
    end
    
    %need to update g score from gUpDate
    if (fun == 31 || fun == 32) && ~cont
        
        g(C) = gUpDate;
        
    else
        %indexUpDate = sort([C;S]);
        g([C;S]) = gUpDate;
        
    end
    
    
    if fun == 31 || fun == 32
        cont = false;
    end
    
    
    [upC, maxIndex] = max(g(C));
    [downC, ~] = min(g(C));
    
    
    threshold = downC + beta*(upC - downC);
    
    %index by g
    [RCL, ~] = find(g(C) >= threshold);
    
    %[upC downC length(RCL)]
    
    %index by node
    RCL = C(RCL);
    
    if ~isempty(RCL)
        
        r = random('unid',length(RCL));
        %randAdd = RCL(r);
        
        S = [S; RCL(r)];
        
        %[RCL(r) upC C(maxIndex)]
        
    else
        S = [S; C(maxIndex)];
    end
    
    
    
    % need to update C; should be neighbor of S
    [~, J] = ind2sub(size(A(S,:)), find(A(S,:)));
    
    J = unique(J);
    % returns the data in J that is not in S i.e J-S
    C = setdiff(J,S);
    C = sort(C);
    C = C(:);
    
    counter = counter + 1;
    
    %added
    C = C(randsample(length(C),ceil(sampleRate*length(C))));

    
end


end